Struct compose_spec::service::ConfigOrSecret
source · pub struct ConfigOrSecret {
pub source: Identifier,
pub target: Option<PathBuf>,
pub uid: Option<u32>,
pub gid: Option<u32>,
pub mode: Option<u32>,
pub extensions: Extensions,
}Expand description
Long syntax config or secret configuration.
Config
Configs allow services to adapt their behavior without the need to rebuild a
container image. Services can only access configs when explicitly granted by the
configs field.
Secret
Secrets grant access to sensitive data defined by the top-level
secrets on a per-service basis.
Fields
source: Identifiertarget: Option<PathBuf>Configs: The path and name of the file to be mounted in the service’s task containers.
Defaults to /<source> if not specified.
Secrets: The name of the file to be mounted in /run/secrets/ in the service’s task
containers. Defaults to source if not specified.
uid: Option<u32>The numeric UID that owns the mounted config/secret file within the service’s task containers.
Default value when not specified is the UID from the container image’s USER.
(De)serialized from/to a string.
gid: Option<u32>The numeric GID that owns the mounted config/secret file within the service’s task containers.
Default value when not specified is the GID from the container image’s USER.
(De)serialized from/to a string.
mode: Option<u32>The permissions for the file that is mounted within the service’s task containers.
Default value is world-readable permissions (mode 0o444). The writable bit must be ignored
if set. The executable bit may be set.
Note that, when deserializing with serde_yaml, octal numbers must start with 0o, e.g.
0o555, otherwise, they are interpreted as decimal numbers. Unfortunately, for
serialization, there is no way to specify that a number should be serialized in octal form.
extensions: ExtensionsExtension values, which are (de)serialized via flattening.