pub struct VolumesFrom {
pub source: VolumesFromSource,
pub read_only: bool,
}Expand description
Fields
source: VolumesFromSourceSource of the volumes to mount, either another service or an externally managed container.
read_only: boolWhether to mount the volumes as read-only.
Implementations
Sourceimpl VolumesFrom
impl VolumesFrom
Sourcepub fn parse<T>(volumes_from: T) -> Result<Self, InvalidIdentifierError>
pub fn parse<T>(volumes_from: T) -> Result<Self, InvalidIdentifierError>
Parse a VolumesFrom from a string in the format [container:]{identifier}[:ro|rw].
Errors
Returns an error if the service or container is not a valid Identifier.