Struct compose_spec::Name
source · pub struct Name(/* private fields */);Expand description
Validated Compose project name.
Names cannot be empty, they must start with a lowercase ASCII letter (a-z) or digit (0-9), and must only contain lowercase ASCII letters (a-z), digits (0-9), underscores (_), or dashes (-).
Implementations
sourceimpl Name
impl Name
sourcepub fn new<T>(name: T) -> Result<Self, InvalidNameError>
pub fn new<T>(name: T) -> Result<Self, InvalidNameError>
Create a new Name, validating the given string.
Errors
Returns an error if the given string is not a valid Name. Names cannot be empty, they
must start with a lowercase ASCII letter (a-z) or digit (0-9), and must only contain
lowercase ASCII letters (a-z), digits (0-9), underscores (_), or dashes (-).